API Reference
=============

This section provides detailed documentation for all qfinbox modules and functions.

.. toctree::
   :maxdepth: 2

   modules

Core Modules
------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   qfinbox

Module Overview
---------------

The qfinbox library currently provides basic package metadata and version information.
Additional modules will be documented here as they are implemented.

.. note::
   This API documentation is automatically generated from the source code.
   Documentation will expand as new features are added to the library.
